/*
 * Archivo de cadenas traducibles generado por Glade.
 * Añada este archivo a su POTFILES.in de su proyecto.
 * NO lo compile como parte de su aplicación.
 */

gchar *s = N_("Storage Device Manager");
gchar *s = N_("Type");
gchar *s = N_("Mountpoint");
gchar *s = N_("Name");
gchar *s = N_("Options");
gchar *s = N_("Set defaults");
gchar *s = N_("Assistant");
gchar *s = N_("Mount");
gchar *s = N_("Remove");
gchar *s = N_("<b>Information</b>");
gchar *s = N_("General Configuration");
gchar *s = N_("name");
gchar *s = N_("vendor");
gchar *s = N_("model");
gchar *s = N_("serial");
gchar *s = N_("Name");
gchar *s = N_("Vendor");
gchar *s = N_("Model");
gchar *s = N_("Serial");
gchar *s = N_("Bus");
gchar *s = N_("bus");
gchar *s = N_("<b>Attributes</b>");
gchar *s = N_("Up");
gchar *s = N_("Down");
gchar *s = N_("Edit");
gchar *s = N_("Delete");
gchar *s = N_("New");
gchar *s = N_("<b>Rules</b>");
gchar *s = N_("Dynamic configuration rules");
